# infuradj
`infuradj` is a Python library that is used for sending transactions to Ethereum network via Infura.io.

## Install

To install the library you can do:

```
pip install infuradj
```

or 

```
pip install git+https://github.com/dastanbeksamatov/django-infura.git
```

## Examples

After you have installed the library you can use it in your library like this:

```
from infuradj import send_tx


```

## API
`tx`

Sends transaction to chain with infura.io

